## Summary

<!-- What does this PR change and why? Be concise. -->

## Type of change

- [ ] Bug fix
- [ ] New feature / enhancement
- [ ] Notebook update
- [ ] Documentation / capstone
- [ ] Chore (deps, CI, tooling)

## Checklist

- [ ] Tests pass (`make test`)
- [ ] Linting is clean (`make lint`)
- [ ] Changes are focused and minimal
